@@ -59,4 +59,8 @@ void CModelComponent::ExportToObj(const std::string &arOutputFilePath, bool aWit
 
 int CModelComponent::Export(const std::string &arOutputFilePath, const std::string& arFileType){
     return CModel(*this).Export(arOutputFilePath, arFileType);
+}
+
+void* CModelComponent::ExportToBlob(const std::string& arFileType) {
+    return CModel(*this).ExportToBlob(arFileType);
 }
\ No newline at end of file
